@@ -1,14 +1,13 @@
 import itertools
 import logging
 import operator
-import re
 from functools import reduce
 from typing import List, Tuple, Optional, Union, Generator
 
-from checkov.common.bridgecrew.platform_integration import bc_integration
+from checkov.common.bridgecrew.integration_features.features.policy_metadata_integration import integration as metadata_integration
 from checkov.common.parsers.node import DictNode, StrNode, ListNode
-from checkov.common.comment.enum import COMMENT_REGEX
 from checkov.common.typing import _SkippedCheck
+from checkov.common.util.suppression import collect_suppressions_for_context
 
 ENDLINE = "__endline__"
 STARTLINE = "__startline__"
@@ -42,7 +41,7 @@ class ContextParser(object):
                 )
                 self._set_in_dict(self.cf_template, ref, default_value)
 
-                ## TODO - Add Variable Eval Message for Output
+                # TODO - Add Variable Eval Message for Output
                 # Output in Checkov looks like this:
                 # Variable versioning (of /.) evaluated to value "True" in expression: enabled = ${var.versioning}
 
@@ -113,24 +112,9 @@ class ContextParser(object):
 
     @staticmethod
     def collect_skip_comments(entity_code_lines: List[Tuple[int, str]], resource_config: Optional[DictNode] = None) -> List[_SkippedCheck]:
-        skipped_checks = []
-        bc_id_mapping = bc_integration.get_id_mapping()
-        ckv_to_bc_id_mapping = bc_integration.get_ckv_to_bc_id_mapping()
-        for line in entity_code_lines:
-            skip_search = re.search(COMMENT_REGEX, str(line))
-            if skip_search:
-                skipped_check: _SkippedCheck = {
-                    "id": skip_search.group(2),
-                    "suppress_comment": skip_search.group(3)[1:] if skip_search.group(3) else "No comment provided",
-                }
-                # No matter which ID was used to skip, save the pair of IDs in the appropriate fields
-                if bc_id_mapping and skipped_check["id"] in bc_id_mapping:
-                    skipped_check["bc_id"] = skipped_check["id"]
-                    skipped_check["id"] = bc_id_mapping[skipped_check["id"]]
-                elif ckv_to_bc_id_mapping:
-                    skipped_check["bc_id"] = ckv_to_bc_id_mapping.get(skipped_check["id"])
+        skipped_checks = collect_suppressions_for_context(code_lines=entity_code_lines)
 
-                skipped_checks.append(skipped_check)
+        bc_id_mapping = metadata_integration.bc_to_ckv_id_mapping
         if resource_config:
             metadata = resource_config.get("Metadata")
             if metadata:
@@ -148,8 +132,8 @@ class ContextParser(object):
                         if bc_id_mapping and skipped_check["id"] in bc_id_mapping:
                             skipped_check["bc_id"] = skipped_check["id"]
                             skipped_check["id"] = bc_id_mapping[skipped_check["id"]]
-                        elif ckv_to_bc_id_mapping:
-                            skipped_check["bc_id"] = ckv_to_bc_id_mapping.get(skipped_check["id"])
+                        elif metadata_integration.check_metadata:
+                            skipped_check["bc_id"] = metadata_integration.get_bc_id(skipped_check["id"])
 
                         skipped_checks.append(skipped_check)
 
