@@ -13,11 +13,6 @@ class LengthEqualsAttributeSolver(BaseAttributeSolver):
             return False
 
         attr = vertex.get(attribute)  # type:ignore[arg-type]  # due to attribute can be None
-        # if this value contains an underendered variable, then we cannot evaluate the check,
-        # so return True (since we cannot return UNKNOWN)
-        if self._is_variable_dependant(attr, vertex['source_']):
-            return True
-
         if isinstance(attr, Sized):
             return len(attr) == force_int(self.value)
 
