@@ -26,23 +26,6 @@ if TYPE_CHECKING:
 _Definitions = TypeVar("_Definitions")
 
 
-def enable_image_referencer(
-    bc_integration: BcPlatformIntegration, frameworks: Iterable[str] | None, skip_frameworks: Iterable[str] | None
-) -> bool:
-    """Checks, if Image Referencer should be enabled"""
-
-    if skip_frameworks and CheckType.SCA_IMAGE in skip_frameworks:
-        return False
-
-    if bc_integration.bc_api_key:
-        if not frameworks:
-            return True
-        if any(framework in frameworks for framework in ("all", CheckType.SCA_IMAGE)):
-            return True
-
-    return False
-
-
 def fix_related_resource_ids(report: Report | None, tmp_dir: str) -> None:
     """Remove tmp dir prefix from 'relatedResourceId'"""
 
