@@ -28,10 +28,12 @@ from checkov.common.bridgecrew.integration_features.features.policy_metadata_int
     integration as policy_metadata_integration
 from checkov.common.bridgecrew.integration_features.features.repo_config_integration import \
     integration as repo_config_integration
+from checkov.common.bridgecrew.integration_features.features.suppressions_integration import \
+    integration as suppressions_integration
 from checkov.common.bridgecrew.integration_features.integration_feature_registry import integration_feature_registry
 from checkov.common.bridgecrew.platform_integration import bc_integration
+from checkov.common.bridgecrew.integration_features.features.licensing_integration import integration as licensing_integration
 from checkov.common.goget.github.get_git import GitGetter
-from checkov.common.images.image_referencer import enable_image_referencer
 from checkov.common.output.baseline import Baseline
 from checkov.common.bridgecrew.check_type import CheckType
 from checkov.common.runners.runner_registry import RunnerRegistry, OUTPUT_CHOICES, SUMMARY_POSITIONS
@@ -107,6 +109,19 @@ DEFAULT_RUNNERS = (
 )
 
 
+def exit_run(no_fail_on_crash: bool) -> None:
+    exit(0) if no_fail_on_crash else exit(2)
+
+
+def commit_repository(config: Namespace) -> Optional[str]:
+    try:
+        return bc_integration.commit_repository(config.branch)
+    except Exception:
+        logging.debug("commit_repository failed, exiting", exc_info=True)
+        exit_run(config.no_fail_on_crash)
+        return ""
+
+
 def run(banner: str = checkov_banner, argv: List[str] = sys.argv[1:]) -> Optional[int]:
     default_config_paths = get_default_config_paths(sys.argv[1:])
     parser = ExtArgumentParser(description='Infrastructure as code static analysis',
@@ -147,7 +162,7 @@ def run(banner: str = checkov_banner, argv: List[str] = sys.argv[1:]) -> Optiona
                   'and either remove the --skip-download option, or use the --include-all-checkov-policies and / or '
                   '--external-checks-dir options.',
                   file=sys.stderr)
-            exit(2)
+            exit_run(config.no_fail_on_crash)
         elif config.skip_download:
             print('You are using an API key along with --skip-download but not --include-all-checkov-policies. '
                   'With these arguments, Checkov cannot fetch metadata to determine what is a local Checkov-only '
@@ -172,12 +187,6 @@ def run(banner: str = checkov_banner, argv: List[str] = sys.argv[1:]) -> Optiona
     if config.var_file:
         config.var_file = [os.path.abspath(f) for f in config.var_file]
 
-    run_image_referencer = enable_image_referencer(
-        bc_integration=bc_integration,
-        frameworks=config.framework,
-        skip_frameworks=config.skip_framework,
-    )
-
     runner_filter = RunnerFilter(framework=config.framework, skip_framework=config.skip_framework, checks=config.check,
                                  skip_checks=config.skip_check, include_all_checkov_policies=config.include_all_checkov_policies,
                                  download_external_modules=bool(convert_str_to_bool(config.download_external_modules)),
@@ -187,9 +196,10 @@ def run(banner: str = checkov_banner, argv: List[str] = sys.argv[1:]) -> Optiona
                                  all_external=config.run_all_external_checks, var_files=config.var_file,
                                  skip_cve_package=config.skip_cve_package, show_progress_bar=not config.quiet,
                                  use_enforcement_rules=config.use_enforcement_rules,
-                                 run_image_referencer=run_image_referencer,
                                  enable_secret_scan_all_files=bool(convert_str_to_bool(config.enable_secret_scan_all_files)),
-                                 block_list_secret_scan=config.block_list_secret_scan)
+                                 block_list_secret_scan=config.block_list_secret_scan,
+                                 deep_analysis=config.deep_analysis,
+                                 repo_root_for_plan_enrichment=config.repo_root_for_plan_enrichment)
 
     if outer_registry:
         runner_registry = outer_registry
@@ -260,7 +270,7 @@ def run(banner: str = checkov_banner, argv: List[str] = sys.argv[1:]) -> Optiona
                     logger.warning(f"Unable to report contributor metrics due to: {e}")
 
         except MaxRetryError:
-            return None
+            exit_run(config.no_fail_on_crash)
         except Exception:
             if bc_integration.prisma_api_url:
                 message = 'An error occurred setting up the Prisma Cloud platform integration. ' \
@@ -273,7 +283,7 @@ def run(banner: str = checkov_banner, argv: List[str] = sys.argv[1:]) -> Optiona
             else:
                 logger.error(message)
                 logger.error('Please try setting the environment variable LOG_LEVEL=DEBUG and re-running the command, and provide the output to support')
-            return None
+            exit_run(config.no_fail_on_crash)
     else:
         logger.debug('No API key found. Scanning locally only.')
         config.include_all_checkov_policies = True
@@ -298,17 +308,21 @@ def run(banner: str = checkov_banner, argv: List[str] = sys.argv[1:]) -> Optiona
                   'policies will get evaluated. Please resolve the error above or re-run with the --include-all-checkov-policies argument '
                   '(but note that this will not include any custom platform configurations or policy metadata).',
                   file=sys.stderr)
-            exit(2)
+            exit_run(config.no_fail_on_crash)
 
     bc_integration.get_prisma_build_policies(config.policy_metadata_filter)
 
     integration_feature_registry.run_pre_scan()
 
+    runner_filter.run_image_referencer = licensing_integration.should_run_image_referencer()
+
     runner_filter.filtered_policy_ids = policy_metadata_integration.filtered_policy_ids
     logger.debug(f"Filtered list of policies: {runner_filter.filtered_policy_ids}")
 
     runner_filter.excluded_paths = runner_filter.excluded_paths + list(repo_config_integration.skip_paths)
 
+    runner_filter.set_suppressed_policies(suppressions_integration.get_policy_level_suppressions())
+
     if config.use_enforcement_rules:
         runner_filter.apply_enforcement_rules(repo_config_integration.code_category_configs)
 
@@ -346,7 +360,7 @@ def run(banner: str = checkov_banner, argv: List[str] = sys.argv[1:]) -> Optiona
                 bc_integration.persist_git_configuration(os.getcwd(), git_configuration_folders)
                 bc_integration.persist_scan_results(scan_reports)
                 bc_integration.persist_run_metadata(run_metadata)
-                url = bc_integration.commit_repository(config.branch)
+                url = commit_repository(config)
 
             if config.create_baseline:
                 overall_baseline = Baseline()
@@ -390,7 +404,7 @@ def run(banner: str = checkov_banner, argv: List[str] = sys.argv[1:]) -> Optiona
         bc_integration.persist_image_scan_results(runner.raw_report, config.dockerfile_path, config.docker_image,
                                                   config.branch)
         bc_integration.persist_run_metadata(run_metadata)
-        url = bc_integration.commit_repository(config.branch)
+        url = commit_repository(config)
         exit_code = runner_registry.print_reports(results, config, url=url)
         return exit_code
     elif config.file:
@@ -415,7 +429,7 @@ def run(banner: str = checkov_banner, argv: List[str] = sys.argv[1:]) -> Optiona
             bc_integration.persist_git_configuration(os.getcwd(), git_configuration_folders)
             bc_integration.persist_scan_results(scan_reports)
             bc_integration.persist_run_metadata(run_metadata)
-            url = bc_integration.commit_repository(config.branch)
+            url = commit_repository(config)
         exit_code = runner_registry.print_reports(scan_reports, config, url=url, created_baseline_path=created_baseline_path, baseline=baseline)
         return exit_code
     elif not config.quiet:
@@ -649,6 +663,15 @@ def add_parser_args(parser: ArgumentParser) -> None:
                help="exclude extra resources (resources without violations) from report output",
                action='store_true',
                env_var='CKV_SKIP_RESOURCES_WITHOUT_VIOLATIONS')
+    parser.add('--deep-analysis',
+               default=False,
+               action='store_true',
+               help='Enable combine tf graph and rf plan graph')
+    parser.add('--no-fail-on-crash',
+               default=False,
+               env_var='CKV_NO_FAIL_ON_CRASH',
+               action='store_true',
+               help='Return exit code 0 instead of 2')
 
 
 def get_external_checks_dir(config: Any) -> Any:
