@@ -9,7 +9,7 @@ from checkov.common.sca.commons import should_run_scan
 from checkov.common.sca.output import add_to_report_sca_data
 from checkov.common.typing import _LicenseStatus
 from checkov.common.bridgecrew.platform_integration import bc_integration, FileToPersist
-from checkov.common.models.consts import SUPPORTED_PACKAGE_FILES
+from checkov.common.models.consts import SCANNABLE_PACKAGE_FILES
 from checkov.common.output.report import Report
 from checkov.common.bridgecrew.check_type import CheckType
 from checkov.common.runners.base_runner import BaseRunner, ignored_directories
@@ -21,7 +21,7 @@ class Runner(BaseRunner[None]):
     check_type = CheckType.SCA_PACKAGE  # noqa: CCE003  # a static attribute
 
     def __init__(self, report_type: str = check_type) -> None:
-        super().__init__(file_names=SUPPORTED_PACKAGE_FILES)
+        super().__init__(file_names=SCANNABLE_PACKAGE_FILES)
         self._check_class: str | None = None
         self._code_repo_path: Path | None = None
         self.report_type = report_type
@@ -63,7 +63,8 @@ class Runner(BaseRunner[None]):
         self._check_class = f"{scanner.__module__}.{scanner.__class__.__qualname__}"
         scan_results = scanner.scan()
 
-        # logging.info(f"SCA package scanning successfully scanned {len(scan_results)} files")
+        if scan_results:
+            logging.info(f"SCA package scanning successfully scanned {len(scan_results)} files")
         return scan_results
 
     def run(
@@ -131,7 +132,7 @@ class Runner(BaseRunner[None]):
         package_files_to_persist: List[FileToPersist] = []
         if root_path:
             for file_path in root_path.glob("**/*"):
-                if file_path.name in SUPPORTED_PACKAGE_FILES and not any(
+                if file_path.name in SCANNABLE_PACKAGE_FILES and not any(
                         p in file_path.parts for p in excluded_paths) and file_path.name not in excluded_file_names:
                     file_path_str = str(file_path)
                     package_files_to_persist.append(
@@ -144,7 +145,7 @@ class Runner(BaseRunner[None]):
                 if not file_path.exists():
                     logging.warning(f"File {file_path} doesn't exist")
                     continue
-                if file_path.name in SUPPORTED_PACKAGE_FILES:
+                if file_path.name in SCANNABLE_PACKAGE_FILES:
                     package_files_to_persist.append(FileToPersist(file, os.path.relpath(file, root_folder)))
 
         logging.info(f"{len(package_files_to_persist)} sca package files found.")
