@@ -20,12 +20,14 @@ from detect_secrets.plugins.base import BasePlugin
 from detect_secrets.util.filetype import FileType
 from detect_secrets.util.filetype import determine_file_type
 
+from checkov.secrets.parsers.terraform.multiline_parser import terraform_multiline_parser
+from checkov.secrets.parsers.terraform.single_line_parser import terraform_single_line_parser
 from checkov.secrets.runner import SOURCE_CODE_EXTENSION
-from checkov.common.parsers.multiline_parser import BaseMultiLineParser
-from checkov.common.parsers.yaml.multiline_parser import yml_multiline_parser
-from checkov.common.parsers.json.multiline_parser import json_multiline_parser
+from checkov.secrets.parsers.yaml.multiline_parser import yml_multiline_parser
+from checkov.secrets.parsers.json.multiline_parser import json_multiline_parser
 
 if TYPE_CHECKING:
+    from checkov.secrets.parsers.multiline_parser import BaseMultiLineParser
     from detect_secrets.core.potential_secret import PotentialSecret
     from detect_secrets.util.code_snippet import CodeSnippet
 
@@ -93,6 +95,30 @@ QUOTES_REQUIRED_FOLLOWED_BY_COLON_VALUE_SECRET_REGEX = re.compile(
     flags=re.IGNORECASE,
 )
 
+FOLLOWED_BY_EQUAL_VALUE_KEYWORD_REGEX = re.compile(
+    # e.g. var = MY_PASSWORD_123
+    r'{whitespace}({key})?={whitespace}({quote}?){words}{denylist}({closing})?(\3)'.format(
+        key=KEY,
+        whitespace=OPTIONAL_WHITESPACE,
+        quote=QUOTE,
+        words=AFFIX_REGEX,
+        denylist=DENY_LIST_REGEX2,
+        closing=CLOSING,
+    ),
+    flags=re.IGNORECASE,
+)
+
+FOLLOWED_BY_EQUAL_VALUE_SECRET_REGEX = re.compile(
+    # e.g. var = Zmlyc3Rfc2VjcmV0X2hlcmVfd2hvYV9tdWx0aWxsaW5lX3Nob3VsZF93b3JrXzE==
+    r'{whitespace}({key})?={whitespace}({quote}?)({secret})(\3)'.format(
+        key=KEY,
+        whitespace=OPTIONAL_WHITESPACE,
+        quote=QUOTE,
+        secret=SECRET,
+    ),
+    flags=re.IGNORECASE,
+)
+
 #  if the current regex is not enough, can add more regexes to check
 
 YML_PAIR_VALUE_KEYWORD_REGEX_TO_GROUP = {
@@ -111,20 +137,42 @@ JSON_PAIR_VALUE_SECRET_REGEX_TO_GROUP = {
     QUOTES_REQUIRED_FOLLOWED_BY_COLON_VALUE_SECRET_REGEX: 4,
 }
 
+TERRAFORM_PAIR_VALUE_KEYWORD_REGEX_TO_GROUP = {
+    FOLLOWED_BY_EQUAL_VALUE_KEYWORD_REGEX: 4,
+}
+
+TERRAFORM_PAIR_VALUE_SECRET_REGEX_TO_GROUP = {
+    FOLLOWED_BY_EQUAL_VALUE_SECRET_REGEX: 4,
+}
 
 REGEX_VALUE_KEYWORD_BY_FILETYPE = {
     FileType.YAML: YML_PAIR_VALUE_KEYWORD_REGEX_TO_GROUP,
     FileType.JSON: JSON_PAIR_VALUE_KEYWORD_REGEX_TO_GROUP,
+    FileType.TERRAFORM: TERRAFORM_PAIR_VALUE_KEYWORD_REGEX_TO_GROUP,
 }
 
 REGEX_VALUE_SECRET_BY_FILETYPE = {
     FileType.YAML: YML_PAIR_VALUE_SECRET_REGEX_TO_GROUP,
     FileType.JSON: JSON_PAIR_VALUE_SECRET_REGEX_TO_GROUP,
+    FileType.TERRAFORM: TERRAFORM_PAIR_VALUE_SECRET_REGEX_TO_GROUP,
+}
+
+SINGLE_LINE_PARSER = {
+    FileType.TERRAFORM: terraform_single_line_parser,
 }
 
 MULTILINE_PARSERS = {
-    FileType.YAML: yml_multiline_parser,
-    FileType.JSON: json_multiline_parser,
+    FileType.YAML: (
+        (FileType.YAML, yml_multiline_parser),
+    ),
+    FileType.JSON: (
+        (FileType.JSON, json_multiline_parser),
+    ),
+    FileType.TERRAFORM: (
+        (FileType.TERRAFORM, terraform_multiline_parser),
+        (FileType.JSON, json_multiline_parser),
+        (FileType.YAML, yml_multiline_parser),
+    ),
 }
 
 
@@ -149,15 +197,29 @@ class EntropyKeywordCombinator(BasePlugin):
             raw_context: CodeSnippet | None = None,
             **kwargs: Any,
     ) -> set[PotentialSecret]:
-        is_iac = f".{filename.split('.')[-1]}" not in SOURCE_CODE_EXTENSION
-        filetype = determine_file_type(filename)
-        multiline_parser = MULTILINE_PARSERS.get(filetype)
+        if len(line) > MAX_LINE_LENGTH:
+            # to keep good performance we skip long lines
+            return set()
 
-        if len(line) <= MAX_LINE_LENGTH:
-            if is_iac:
-                # classic key-value pair
-                keyword_on_key = self.keyword_scanner.analyze_line(filename, line, line_number, **kwargs)
-                if keyword_on_key:
+        is_iac = f".{filename.split('.')[-1]}" not in SOURCE_CODE_EXTENSION
+        if is_iac:
+            filetype = determine_file_type(filename)
+            single_line_parser = SINGLE_LINE_PARSER.get(filetype)
+            multiline_parsers = MULTILINE_PARSERS.get(filetype)
+
+            # classic key-value pair
+            keyword_on_key = self.keyword_scanner.analyze_line(filename, line, line_number, **kwargs)
+            if keyword_on_key:
+                if single_line_parser:
+                    return single_line_parser.detect_secret(
+                        scanners=self.high_entropy_scanners_iac,
+                        filename=filename,
+                        raw_context=raw_context,
+                        line=line,
+                        line_number=line_number,
+                        kwargs=kwargs
+                    )
+                else:
                     return self.detect_secret(
                         scanners=self.high_entropy_scanners_iac,
                         filename=filename,
@@ -166,12 +228,16 @@ class EntropyKeywordCombinator(BasePlugin):
                         kwargs=kwargs
                     )
 
-                # not so classic key-value pair, from multiline, that is only in an array format.
-                # The scan is one-way backwards, so no duplicates expected.
-                elif multiline_parser:
-                    value_keyword_regex_to_group = REGEX_VALUE_KEYWORD_BY_FILETYPE.get(filetype)
-                    secret_keyword_regex_to_group = REGEX_VALUE_SECRET_BY_FILETYPE.get(filetype)
-                    return self.analyze_multiline(
+            # not so classic key-value pair, from multiline, that is only in an array format.
+            # The scan searches forwards and backwards for a potential secret pair, so no duplicates expected.
+            elif multiline_parsers:
+                # iterate over multiple parser and their related file type.
+                # this is needed for file types, which embed other file type parser, ex Terraform with heredoc
+                for parser_file_type, multiline_parser in multiline_parsers:
+                    value_keyword_regex_to_group = REGEX_VALUE_KEYWORD_BY_FILETYPE.get(parser_file_type)
+                    secret_keyword_regex_to_group = REGEX_VALUE_SECRET_BY_FILETYPE.get(parser_file_type)
+
+                    potential_secrets = self.analyze_multiline(
                         filename=filename,
                         line=line,
                         multiline_parser=multiline_parser,
@@ -182,14 +248,19 @@ class EntropyKeywordCombinator(BasePlugin):
                         secret_pattern=secret_keyword_regex_to_group,
                         kwargs=kwargs
                     )
-            else:
-                return self.detect_secret(
-                    scanners=self.high_entropy_scanners,
-                    filename=filename,
-                    line=line,
-                    line_number=line_number,
-                    kwargs=kwargs
-                )
+
+                    if potential_secrets:
+                        # return a possible secret, otherwise check with next parser
+                        return potential_secrets
+        else:
+            return self.detect_secret(
+                scanners=self.high_entropy_scanners,
+                filename=filename,
+                line=line,
+                line_number=line_number,
+                kwargs=kwargs
+            )
+
         return set()
 
     def analyze_multiline(
