@@ -1,5 +1,6 @@
 from checkov.common.models.enums import CheckCategories, CheckResult
 from checkov.terraform.checks.resource.base_resource_value_check import BaseResourceCheck
+from typing import List
 
 
 class DocDBLogging(BaseResourceCheck):
@@ -11,14 +12,14 @@ class DocDBLogging(BaseResourceCheck):
         super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)
 
     def scan_resource_conf(self, conf):
-        self.evaluated_keys = 'enabled_cloudwatch_logs_exports'
         log_types = ["profiler", "audit"]
         if 'enabled_cloudwatch_logs_exports' in conf:
             if all(elem in conf["enabled_cloudwatch_logs_exports"][0] for elem in log_types):
                 return CheckResult.PASSED
-            else:
-                return CheckResult.FAILED
         return CheckResult.FAILED
 
+    def get_evaluated_keys(self) -> List[str]:
+        return ['enabled_cloudwatch_logs_exports']
+
 
 check = DocDBLogging()
