@@ -5,16 +5,18 @@ import logging
 import os
 import re
 from collections.abc import Sequence
+from collections import defaultdict
 from copy import deepcopy
 from json import dumps, loads
 from pathlib import Path
 from typing import Optional, Dict, Mapping, Set, Tuple, Callable, Any, List, Type, TYPE_CHECKING
+import itertools
 
 import deep_merge
 import hcl2
 from lark import Tree
 
-from checkov.common.runners.base_runner import filter_ignored_paths, IGNORE_HIDDEN_DIRECTORY_ENV
+from checkov.common.runners.base_runner import filter_ignored_paths, IGNORE_HIDDEN_DIRECTORY_ENV, strtobool
 from checkov.common.util.consts import DEFAULT_EXTERNAL_MODULES_DIR, RESOLVED_MODULE_ENTRY_NAME
 from checkov.common.util.json_utils import CustomJSONEncoder
 from checkov.common.variables.context import EvaluationContext
@@ -26,7 +28,8 @@ from checkov.terraform.module_loading.content import ModuleContent
 from checkov.terraform.module_loading.module_finder import load_tf_modules
 from checkov.terraform.module_loading.registry import module_loader_registry as default_ml_registry, \
     ModuleLoaderRegistry
-from checkov.common.util.parser_utils import eval_string, find_var_blocks
+from checkov.common.util.parser_utils import eval_string, find_var_blocks, get_current_module_index, is_nested, \
+    get_tf_definition_key, get_module_from_full_path, get_abs_path
 
 if TYPE_CHECKING:
     from typing_extensions import TypeAlias
@@ -58,6 +61,7 @@ class Parser:
         # Tuple is <file>, <module_index>, <name> (see _load_modules)
         self._loaded_modules: Set[Tuple[str, int, str]] = set()
         self.external_variables_data = []
+        self.enable_nested_modules = strtobool(os.getenv('CHECKOV_ENABLE_NESTED_MODULES', 'False'))
 
     def _init(self, directory: str, out_definitions: Optional[Dict],
               out_evaluations_context: Dict[str, Dict[str, EvaluationContext]],
@@ -86,6 +90,8 @@ class Parser:
         if self.env_vars is None:
             self.env_vars = dict(os.environ)
         self.excluded_paths = excluded_paths
+        self.visited_definition_keys = set()
+        self.module_to_resolved = {}
 
     def _check_process_dir(self, directory: str) -> bool:
         if directory not in self._parsed_directories:
@@ -112,6 +118,8 @@ class Parser:
         default_ml_registry.module_content_cache = external_modules_content_cache if external_modules_content_cache else {}
         load_tf_modules(directory)
         self._parse_directory(dir_filter=lambda d: self._check_process_dir(d), vars_files=vars_files)
+        if self.enable_nested_modules:
+            self._update_resolved_modules()
 
     def parse_file(self, file: str, parsing_errors: Optional[Dict[str, Exception]] = None) -> Optional[Dict[str, Any]]:
         if file.endswith(".tf") or file.endswith(".tf.json") or file.endswith(".hcl"):
@@ -177,7 +185,8 @@ class Parser:
                            specified_vars: Optional[Mapping[str, str]] = None,
                            vars_files: Optional[List[str]] = None,
                            root_dir: Optional[str] = None,
-                           excluded_paths: Optional[List[str]] = None):
+                           excluded_paths: Optional[List[str]] = None,
+                           nested_modules_data=None):
         """
     See `parse_directory` docs.
         :param directory:                  Directory in which .tf and .tfvars files will be loaded.
@@ -311,8 +320,12 @@ class Parser:
             logging.debug("Module load loop %d", i)
 
             # Stage 4a: Load eligible modules
+            # Add directory to self._parsed_directories to avoid loading it as sub dir
+            if self.enable_nested_modules:
+                dir_filter(directory)
             has_more_modules = self._load_modules(directory, module_loader_registry, dir_filter,
-                                                  keys_referenced_as_modules, force_final_module_load)
+                                                  keys_referenced_as_modules, force_final_module_load,
+                                                  nested_modules_data=nested_modules_data)
 
             # Stage 4b: Variable resolution round 2 - now with (possibly more) modules
             made_var_changes = False
@@ -352,7 +365,8 @@ class Parser:
 
     def _load_modules(self, root_dir: str, module_loader_registry: ModuleLoaderRegistry,
                       dir_filter: Callable[[str], bool],
-                      keys_referenced_as_modules: Set[str], ignore_unresolved_params: bool = False) -> bool:
+                      keys_referenced_as_modules: Set[str], ignore_unresolved_params: bool = False,
+                      nested_modules_data=None) -> bool:
         """
         Load modules which have not already been loaded and can be loaded (don't have unresolved parameters).
 
@@ -382,7 +396,6 @@ class Parser:
                 continue
 
             for module_index, module_call in enumerate(module_calls):
-
                 if not isinstance(module_call, dict):
                     continue
 
@@ -391,9 +404,19 @@ class Parser:
                     if not isinstance(module_call_data, dict):
                         continue
 
+                    if self.enable_nested_modules:
+                        file_key = self.get_file_key_with_nested_data(file, nested_modules_data)
+                        current_nested_data = (file_key, module_index, module_call_name)
+
+                        resolved_loc_list = []
+                        if current_nested_data in self.module_to_resolved:
+                            resolved_loc_list = self.module_to_resolved[current_nested_data]
+                        self.module_to_resolved[current_nested_data] = resolved_loc_list
+
                     module_address = (file, module_index, module_call_name)
-                    if module_address in self._loaded_modules:
-                        continue
+                    if not self.enable_nested_modules:
+                        if module_address in self._loaded_modules:
+                            continue
 
                     # Variables being passed to module, "source" and "version" are reserved
                     specified_vars = {k: v[0] if isinstance(v, list) else v for k, v in module_call_data.items()
@@ -432,10 +455,14 @@ class Parser:
                             logging.info(f'Got no content for {source}:{version}')
                             continue
 
+                        new_nested_modules_data = {'module_index': module_index, 'file': file,
+                                                   'nested_modules_data': nested_modules_data}
+
                         self._internal_dir_load(directory=content.path(),
                                                 module_loader_registry=module_loader_registry,
                                                 dir_filter=dir_filter, specified_vars=specified_vars,
-                                                keys_referenced_as_modules=keys_referenced_as_modules)
+                                                keys_referenced_as_modules=keys_referenced_as_modules,
+                                                nested_modules_data=new_nested_modules_data)
 
                         module_definitions = {path: self.out_definitions[path] for path in
                                               list(self.out_definitions.keys()) if
@@ -457,22 +484,33 @@ class Parser:
                         #       list pointing to the location of the module data that was resolved. For example:
                         #         "__resolved__": ["/the/path/module/my_module.tf[/the/path/main.tf#0]"]
 
-                        resolved_loc_list = module_call_data.get(RESOLVED_MODULE_ENTRY_NAME)
-                        if resolved_loc_list is None:
-                            resolved_loc_list = []
-                            module_call_data[RESOLVED_MODULE_ENTRY_NAME] = resolved_loc_list
+                        if not self.enable_nested_modules:
+                            resolved_loc_list = module_call_data.get(RESOLVED_MODULE_ENTRY_NAME)
+                            if resolved_loc_list is None:
+                                resolved_loc_list = []
+                                module_call_data[RESOLVED_MODULE_ENTRY_NAME] = resolved_loc_list
 
                         # NOTE: Modules can load other modules, so only append referrer information where it
                         #       has not already been added.
+
                         keys = list(module_definitions.keys())
                         for key in keys:
                             if key.endswith("]") or file.endswith("]"):
                                 continue
                             keys_referenced_as_modules.add(key)
-                            new_key = f"{key}[{file}#{module_index}]"
+                            if self.enable_nested_modules:
+                                new_key = self.get_new_nested_module_key(key, file, module_index, nested_modules_data)
+                                if new_key in self.visited_definition_keys:
+                                    del module_definitions[key]
+                                    del self.out_definitions[key]
+                                    continue
+                            else:
+                                new_key = get_tf_definition_key(key, file, module_index)
                             module_definitions[new_key] = module_definitions[key]
                             del module_definitions[key]
                             del self.out_definitions[key]
+                            if self.enable_nested_modules:
+                                self.visited_definition_keys.add(new_key)
                             if new_key not in resolved_loc_list:
                                 resolved_loc_list.append(new_key)
                             if (file, module_call_name) not in self.module_address_map:
@@ -522,13 +560,23 @@ class Parser:
 
         return module, tf_definitions
 
+    def _update_resolved_modules(self):
+        for key, resolved_list in self.module_to_resolved.items():
+            file_key, module_index, module_name = key
+            if file_key not in self.out_definitions:
+                continue
+            self.out_definitions[file_key]['module'][module_index][module_name][RESOLVED_MODULE_ENTRY_NAME] = resolved_list
+
     def parse_hcl_module_from_tf_definitions(
         self,
         tf_definitions: Dict[str, Dict[str, Any]],
         source_dir: str,
         source: str,
     ) -> Tuple[Module, Dict[str, Dict[str, Any]]]:
-        module_dependency_map, tf_definitions, dep_index_mapping = self.get_module_dependency_map(tf_definitions)
+        if self.enable_nested_modules:
+            module_dependency_map, tf_definitions, dep_index_mapping = self.get_module_dependency_map_support_nested_modules(tf_definitions)
+        else:
+            module_dependency_map, tf_definitions, dep_index_mapping = self.get_module_dependency_map(tf_definitions)
         module = self.get_new_module(
             source_dir=source_dir,
             module_dependency_map=module_dependency_map,
@@ -577,6 +625,26 @@ class Parser:
                 sorted_conf[attribute] = str(values)
         return sorted_conf
 
+    def get_file_key_with_nested_data(self, file, nested_data):
+        if not nested_data:
+            return file
+        nested_str = self.get_file_key_with_nested_data(nested_data.get("file"), nested_data.get('nested_modules_data'))
+        nested_module_name = get_abs_path(nested_str)
+        nested_module_index = nested_data.get('module_index')
+        module_index = get_current_module_index(nested_str)
+        nested_key = nested_str[module_index:]
+        return get_tf_definition_key(file, nested_module_name, nested_module_index, nested_key)
+
+    def get_new_nested_module_key(self, key, file, module_index, nested_data) -> str:
+        if not nested_data:
+            return get_tf_definition_key(key, file, module_index)
+        visited_key_to_add = get_tf_definition_key(key, file, module_index)
+        self.visited_definition_keys.add(visited_key_to_add)
+        nested_key = self.get_new_nested_module_key('', nested_data.get('file'),
+                                                    nested_data.get('module_index'),
+                                                    nested_data.get('nested_modules_data'))
+        return get_tf_definition_key(key, file, module_index, nested_key)
+
     @staticmethod
     def _clean_parser_types_lst(values: list[Any]) -> list[Any]:
         for idx, val in enumerate(values):
@@ -642,6 +710,37 @@ class Parser:
             unevaluated.append(k)
         return next_level, unevaluated
 
+    @staticmethod
+    def get_nested_modules_data_as_list(file_path):
+        path = get_abs_path(file_path)
+        modules_list = []
+
+        while is_nested(file_path):
+            module, index = get_module_from_full_path(file_path)
+            modules_list.append((module, index))
+            file_path = module
+        modules_list.reverse()
+        return modules_list, path
+
+    @staticmethod
+    def get_module_dependency_map_support_nested_modules(tf_definitions):
+        module_dependency_map = defaultdict(list)
+        dep_index_mapping = defaultdict(list)
+        for tf_definition_key in tf_definitions.keys():
+            if not is_nested(tf_definition_key):
+                dir_name = os.path.dirname(tf_definition_key)
+                module_dependency_map[dir_name].append([])
+                continue
+            modules_list, path = Parser.get_nested_modules_data_as_list(tf_definition_key)
+            dir_name = os.path.dirname(path)
+            module_dependency_map[dir_name].append([m for m, i in modules_list])
+            dep_index_mapping[(path, modules_list[-1][0])].append(modules_list[-1][1])
+
+        for key, dir_list in module_dependency_map.items():
+            dir_list.sort()
+            module_dependency_map[key] = list(dir_list for dir_list, _ in itertools.groupby(dir_list))
+        return module_dependency_map, tf_definitions, dep_index_mapping
+
     @staticmethod
     def get_module_dependency_map(tf_definitions):
         """
